@@ -426,27 +426,32 @@ class SourceCodeWindow(QWidget):
 
 class DynamicButton(QWidget):
 
-    IconSize = QSize(30, 30)
-    HorizontalSpacing = 2
+    icon_size = QSize(30, 30)
+    horizontal_spacing = 2
 
     def __init__(self, label: str, func: Callable,
-                 icon_path: Path | str = None, final_stretch=True, size: QSize = IconSize):
+                 icon_path: Path | str = None,
+                 icon_selected_path: Path | str = None,
+                 final_stretch=True,
+                 icon_size: QSize = icon_size):
         super().__init__()
+        self.source_code_window = None
         self._function = func
         self._label = label
         self._icon = None
 
-        self.icon_path = str(icon_path or HERE / "icons/023-evaluate.svg")
+        self.icon_path = str(icon_path or HERE / "icons/script-function.svg")
+        self.icon_selected_path = str(icon_selected_path or HERE / "icons/script-function-selected.svg")
 
         layout = QHBoxLayout()
         layout.setContentsMargins(0, 0, 0, 0)
         self.setLayout(layout)
 
-        label_icon = IconLabel(icon_path=self.icon_path, size=size)
+        self.label_icon = IconLabel(icon_path=self.icon_path, size=icon_size)
         label_text = QLabel(self.function_display_name)
 
-        layout.addWidget(label_icon)
-        layout.addSpacing(self.HorizontalSpacing)
+        layout.addWidget(self.label_icon)
+        layout.addSpacing(self.horizontal_spacing)
         layout.addWidget(label_text)
 
         if final_stretch:
@@ -466,6 +471,14 @@ class DynamicButton(QWidget):
         self.source_code_window = SourceCodeWindow(self.function)
         self.source_code_window.show()
 
+    def select(self):
+        self.label_icon.set_icon_path(self.icon_selected_path)
+        self.label_icon.repaint()
+
+    def deselect(self):
+        self.label_icon.set_icon_path(self.icon_path)
+        self.label_icon.repaint()
+
     @property
     def function(self) -> Callable:
         return self._function
@@ -752,6 +765,7 @@ class View(QMainWindow):
         self._kernel: Optional[MyKernel] = None
         self._buttons = []
         self.input_queue: Queue = Queue()
+        self.previous_selected_button: Optional[DynamicButton] = None
 
         # Keep a record of the GUI Apps, because if their reference is garbage collected they will crash
 
@@ -762,7 +776,7 @@ class View(QMainWindow):
         desktop_widget = QApplication.desktop()
         desktop_screen = desktop_widget.screenNumber(self)
         desktop_geometry = desktop_widget.availableGeometry(screen=desktop_screen)
-        print(f"{desktop_screen = }, {desktop_geometry = }")
+        # print(f"{desktop_screen = }, {desktop_geometry = }")
 
         self.setMaximumSize(desktop_geometry.width(), desktop_geometry.height())
 
@@ -783,6 +797,7 @@ class View(QMainWindow):
         vbox = QVBoxLayout()
 
         self._splitter = QSplitter(Qt.Vertical)
+        self._splitter.setChildrenCollapsible(False)
 
         self._buttons_panel = FunctionButtonsPanel()
         self._args_panel: QWidget = None
@@ -849,7 +864,7 @@ class View(QMainWindow):
 
     def _start_new_kernel(self):
         name = self.kernel_panel.selected_kernel
-        print(f"Starting new kernel {name}...")
+        # print(f"Starting new kernel {name}...")
         self._kernel = MyKernel(name)
         self._console_panel.append(f"New kernel '{name}' started...")
         info = self._kernel.get_kernel_info()
@@ -928,6 +943,17 @@ class View(QMainWindow):
 
         self._args_panel = args_panel
 
+        if self.previous_selected_button is not None:
+            self.previous_selected_button.deselect()
+
+        button.select()
+        self.previous_selected_button = button
+
+        # This scrolls the buttons panel to make the selected button is still visible
+        # after the Arguments panel appeared.
+
+        self._buttons_panel.ensureWidgetVisible(button)
+
     @pyqtSlot(object)
     def function_output(self, data: object):
         self._console_panel.append(str(data))
